# z/OS Edit

This GUI application provides a way to browse/edit datasets on z/OS as well as read job output from JES2.

## Installation

`pip install zosedit`

## Usage

Once installed with Pip, to run the application, simply type `zosedit` in your terminal.

